# BigEarthNet Common
> A collection of common tools to interact with the BigEarthNet dataset.

[![Tests](https://img.shields.io/github/workflow/status/kai-tub/bigearthnet_common/CI?color=dark-green&label=%20Tests)](https://github.com/kai-tub/bigearthnet_common//actions/workflows/main.yml)
[![License](https://img.shields.io/pypi/l/bigearthnet-common?color=dark-green)](https://github.com/kai-tub/bigearthnet_common//blob/main/LICENSE)
[![Python Versions](https://img.shields.io/pypi/pyversions/bigearthnet-common)](https://pypi.org/project/bigearthnet-common)
[![PyPI version](https://img.shields.io/pypi/v/bigearthnet-common)](https://pypi.org/project/bigearthnet-common)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/bigearthnet-common?color=dark-green)](https://anaconda.org/conda-forge/bigearthnet-common)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)
[![Auto Release](https://img.shields.io/badge/release-auto.svg?colorA=888888&colorB=blueviolet&label=auto&logo=data:image/png;base64, )](https://github.com/intuit/auto)
<!-- WIP: [![MyPy Type Checker](https://img.shields.io/badge/%20type_checker-mypy-%231674b1?style=flat&color=dark-green)](http://mypy-lang.org/) -->

This library provides a collection of high-level tools to better work with the [BigEarthNet](www.bigearth.net) dataset.

`bigearthnet_common` tries to:

1. Collect the most relevant _constants_ into a single place to reduce the time spent looking for these, like:
   - The 19 or 43 class nomenclature strings
   - URL
   - Band statistics (mean/variance) as integer and float
   - Channel names
   - etc.
2. Provide common metadata related functions
   - Safe JSON parser for S1/S2
   - Get the original split
   - Get a list of snowy/cloudy patches
   - Convert the _old_ labels to the _new_ label nomenclature
   - Generate multi-hot encoded label views
3. Easily filter patches and generate subsets as CSV files
4. Allow to quickly test code on BigEarthNet data without requiring to download the entire archvie

## Installation
The package is available via PyPI and can be installed with:
- `pip install bigearthnet_common`

The package has _Python-only_ dependencies and should cause no issues in more complex Conda environments with various binaries.

## Review constants
To quickly search for BigEarthNet constants of interest, call:
- `ben_constants_prompt` or
- `python -m bigearthnet_common.constants`

## Sets generator
To generate sets/subsets from the data and to store them as a CSV file, use:
- `ben_build_csv_sets --help`

This command-line tool lets the user easily create subsets from common constraints.
To generate a CSV file that contains all Sentinel-2 patches from Serbia only during the Summer and Spring months, call the function as:
- `ben_build_csv_sets <FILE_PATH> S2 --seasons Winter --seasons Summer --countries Serbia --remove-unrecommended-dl-patches`

:::{note}

By default, this tool will always remove the _unrecommended_ patches, i.e., patches that contain seasonal snow, shadows, clouds, or that have no labels in the 19-class nomenclature

:::


## Describe patch
The library provides a tool to quickly visualize meta-data information about each patch:
```sh
ben_describe_patch <S1/S2 patch name>
```
